@@ -150,7 +150,7 @@ void       gtk_window_set_title                (GtkWindow           *window,
 						const gchar         *title);
 GDK_AVAILABLE_IN_ALL
 const gchar * gtk_window_get_title             (GtkWindow           *window);
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_3_22
 void       gtk_window_set_wmclass              (GtkWindow           *window,
 						const gchar         *wmclass_name,
 						const gchar         *wmclass_class);
@@ -366,7 +366,7 @@ GDK_AVAILABLE_IN_ALL
 gboolean gtk_window_propagate_key_event   (GtkWindow        *window,
 					   GdkEventKey      *event);
 
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_3_24_FOR(gtk_window_present_with_time)
 void     gtk_window_present            (GtkWindow *window);
 GDK_AVAILABLE_IN_ALL
 void     gtk_window_present_with_time  (GtkWindow *window,
@@ -439,11 +439,11 @@ GDK_AVAILABLE_IN_ALL
 void     gtk_window_get_position     (GtkWindow   *window,
                                       gint        *root_x,
                                       gint        *root_y);
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_3_20
 gboolean gtk_window_parse_geometry   (GtkWindow   *window,
                                       const gchar *geometry);
 
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_3_20_FOR(gtk_window_set_default_size)
 void gtk_window_set_default_geometry (GtkWindow *window,
                                       gint       width,
                                       gint       height);
